pub struct CrossFormatGroup {
pub files: Vec<String>,
pub containers: Vec<String>,
pub best_confidence: f64,
}Expand description
A group of files that contain the same content in different formats.
Fields
files: Vec<String>Files in this group.
containers: Vec<String>Containers present in this group.
best_confidence: f64Best confidence score among all pairs in this group.