pub struct ProgressTracker<'a> { /* private fields */ }Expand description
Helper struct for tracking and emitting progress events from dedup algorithms.
Implementations
Sourceimpl<'a> ProgressTracker<'a>
impl<'a> ProgressTracker<'a>
Sourcepub fn new(
reporter: &'a dyn ProgressReporter,
phase: &str,
total: usize,
) -> Self
pub fn new( reporter: &'a dyn ProgressReporter, phase: &str, total: usize, ) -> Self
Create a new tracker for a phase.
Sourcepub fn tick_batch(&mut self, batch_size: usize)
pub fn tick_batch(&mut self, batch_size: usize)
Report that a batch of items has been processed.
Sourcepub fn report_error(&self, item_id: &str, error: &str)
pub fn report_error(&self, item_id: &str, error: &str)
Report an error for an item.
Sourcepub fn is_cancelled(&self) -> bool
pub fn is_cancelled(&self) -> bool
Returns true if cancellation has been requested.