pub struct BuzHash { /* private fields */ }Expand description
Buzhash rolling hash.
Maintains a sliding window over the input and computes a rolling hash that can be updated in O(1) as bytes enter and leave the window.
Implementations