Visual similarity detection for image and video deduplication.
This module provides:
- Perceptual hashing (pHash, dHash, aHash)
- SSIM (Structural Similarity Index Measure)
- Histogram comparison
- Feature extraction and matching
- Near-duplicate detection with configurable thresholds
Structs
- Feature
Point - Feature point for matching.
- Image
- Image representation for processing.
- Perceptual
Hash - Perceptual hash result.
- Ssim
Config - Configuration for SSIM-based thumbnail duplicate detection.
- Ssim
Params - SSIM (Structural Similarity Index) parameters.
- Visual
Similarity - Visual similarity metrics.
Functions
- compare_
histograms - Compare histograms using correlation.
- compare_
images - Compare visual similarity between two images.
- compute_
ahash - Compute average hash (aHash).
- compute_
dhash - Compute difference hash (dHash).
- compute_
histogram - Compute histogram for an image.
- compute_
phash - Compute perceptual hash (pHash) using DCT.
- compute_
ssim - Compute SSIM between two images.
- compute_
whash - Compute wavelet hash (wHash) using Haar wavelet decomposition.
- extract_
features - Extract feature points from an image (simplified SIFT-like).
- find_
ssim_ duplicates - Find SSIM duplicates among a list of files using the default 8×8 config.
- find_
ssim_ duplicates_ with_ config - Find SSIM duplicates among a list of files using a custom config.
- match_
features - Match features between two images.